function [J,C]=opttran(P,rho,mu)

% OPTTRAN  Optimal Transient Stabilization
%
%    OPTTRAN(P,RHO,MU) applys optimal transient stabilization for a given 
%    system P (created with either TF, ZPK, SS, or FRD). RHO is a positive 
%    number used to give a relative weight to 'y1(t)' and 'y2(t)'. MU is a 
%    positive number used to give a relative weight to 'w1(t)' and 'w2(t)'.
%
%    [J,C]=OPTTRAN(P,RHO,MU) returns the optimal performance index J and 
%    the stabilizing controller C.


% Get the numerator and denominator of the system transfer function;
[num,den]=tfdata(P);
a=den{1,1};
b=num{1,1};

% Spectral factorization
b1=rho*b;
d_rhos=spectral(a,b1);
b2=mu*b;
d_mus=spectral(a,b2);

% Pole placement
ds=d_rhos*d_mus;
ptemp=zpkdata(ds);
pole=ptemp{1,1};
C=poleplace(P,pole,0);
[Cnum,Cden]=tfdata(C);
q=Cnum{1,1};
p=Cden{1,1};

% H_2 norm computation
d_rho=tfdata(d_rhos);
d_rho=d_rho{1,1};
d_mu=tfdata(d_mus);
d_mu=d_mu{1,1};
da=d_rho-a;
nda=length(da);
da=da(2:nda);
G1=tf(da,d_rho);
j1=norm2(G1);
G2=tf(b,d_rho);
j2=norm2(G2);
dp=d_mu-p;
ndp=length(dp);
dp=dp(2:ndp);
G3=tf(dp,d_mu);
j3=norm2(G3);
G4=tf(q,d_mu);
j4=norm2(G4);
J=mu^2*j1^2+rho^2*mu^2*j2^2+mu^2*j3^2+j4^2;

% end opttran